@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 import logging
 import os
+import time
 import tempfile
 import pytest
 import xml.etree.ElementTree as ET
@@ -54,6 +55,8 @@ def xml():
     return ET.fromstring(xml_code)
 
 
+
+
 @pytest.fixture
 def bgg():
     return BoardGameGeek()
@@ -75,6 +78,7 @@ def progress_cb(items, total):
 # Test caches
 #
 def test_no_caching():
+    time.sleep(10)
 
     # test that we can disable caching
     bgg = BoardGameGeek(cache=None)
@@ -86,6 +90,8 @@ def test_no_caching():
 
 
 def test_sqlite_caching():
+    time.sleep(10)
+
     # test that we can use the SQLite cache
     # generate a temporary file
     fd, name = tempfile.mkstemp(suffix=".cache")
@@ -121,6 +127,8 @@ def test_get_user_with_invalid_parameters(bgg):
 
 
 def test_get_invalid_user_info(bgg):
+    time.sleep(10)
+
     global progress_called
 
     progress_called = False
@@ -131,6 +139,8 @@ def test_get_invalid_user_info(bgg):
 
 
 def test_get_valid_user_info(bgg, null_logger):
+    time.sleep(10)
+
     global progress_called
 
     progress_called = False
@@ -178,12 +188,13 @@ def test_get_collection_with_invalid_parameters(bgg):
 
 
 def test_get_invalid_users_collection(bgg):
-
+    time.sleep(10)
     collection = bgg.collection(TEST_INVALID_USER)
     assert collection is None
 
 
 def test_get_valid_users_collection(bgg, null_logger):
+    time.sleep(10)
 
     collection = bgg.collection(TEST_VALID_USER)
 
@@ -235,6 +246,8 @@ def test_get_guild_with_invalid_parameters(bgg):
 
 
 def test_get_valid_guild_info(bgg, null_logger):
+    time.sleep(10)
+
     global progress_called
 
     progress_called = False
@@ -270,6 +283,8 @@ def test_get_valid_guild_info(bgg, null_logger):
 
 
 def test_get_invalid_guild_info(bgg):
+    time.sleep(10)
+
     global progress_called
 
     progress_called = False
@@ -282,6 +297,8 @@ def test_get_invalid_guild_info(bgg):
 
 #region game() testing
 def test_get_unknown_game_info(bgg):
+    time.sleep(10)
+
     game = bgg.game(TEST_INVALID_GAME_NAME)
     assert game is None
 
@@ -300,6 +317,8 @@ def test_get_game_with_invalid_parameters(bgg):
 
 
 def check_game(game):
+    time.sleep(10)
+
     assert game is not None
     assert game.name == TEST_GAME_NAME
     assert game.id == TEST_GAME_ID
@@ -307,8 +326,8 @@ def check_game(game):
     assert game.mechanics == ["Area Enclosure", "Card Drafting", "Hand Management", "Worker Placement"]
     assert game.min_players == 1
     assert game.max_players == 5
-    assert game.thumbnail == "http://cf.geekdo-images.com/images/pic259085_t.jpg"
-    assert game.image == "http://cf.geekdo-images.com/images/pic259085.jpg"
+    assert "cf.geekdo-images.com/images/pic259085_t.jpg" in game.thumbnail
+    assert "cf.geekdo-images.com/images/pic259085.jpg" in game.image
     assert game.playing_time == 120
     assert game.min_age == 12
     assert game.categories == ["Economic", "Farming"]
@@ -355,6 +374,8 @@ def check_game(game):
 
 
 def test_get_known_game_info(bgg, null_logger):
+    time.sleep(10)
+
     # use an older game that's not so likely to change
     game = bgg.game(TEST_GAME_NAME)
 
@@ -367,16 +388,21 @@ def test_get_known_game_info(bgg, null_logger):
 
 
 def test_get_known_game_info_by_id(bgg):
+    time.sleep(10)
+
     game = bgg.game(None, game_id=TEST_GAME_ID)
     check_game(game)
 
 
 def test_get_game_id_by_name(bgg):
+    time.sleep(10)
+
     game_id = bgg.get_game_id(TEST_GAME_NAME)
     assert game_id == TEST_GAME_ID
 
 
 def test_get_games_by_name(bgg, null_logger):
+    time.sleep(10)
 
     games = bgg.games("coup")
 
@@ -403,6 +429,8 @@ def test_get_plays_with_invalid_parameters(bgg):
 
 
 def test_get_plays_with_unknown_username_and_id(bgg):
+    time.sleep(10)
+
     plays = bgg.plays(name=TEST_INVALID_USER)
     assert plays is None
 
@@ -412,6 +440,8 @@ def test_get_plays_with_unknown_username_and_id(bgg):
 
 
 def test_get_plays_of_user(bgg, null_logger):
+    time.sleep(10)
+
     global progress_called
 
     plays = bgg.plays(name=TEST_VALID_USER, progress=progress_cb)
@@ -432,10 +462,24 @@ def test_get_plays_of_user(bgg, null_logger):
         assert type(p.game_name) == str
         assert type(p.comment) in [type(None), str]
 
+        assert type(p.players) == list
+        if p.players:
+            for player in p.players:
+                assert hasattr(player, "startposition")
+                assert hasattr(player, "username")
+                assert hasattr(player, "user_id")
+                assert hasattr(player, "name")
+                assert type(player.score) == float
+                assert hasattr(player, "new")
+                assert hasattr(player, "win")
+                assert hasattr(player, "rating")
+
     plays._format(null_logger)
 
 
 def test_get_plays_of_game(bgg, null_logger):
+    time.sleep(10)
+
     global progress_called
 
     plays = bgg.plays(game_id=TEST_GAME_ID_2, progress=progress_cb)
@@ -486,7 +530,7 @@ def test_get_hot_items_invalid_type(bgg):
 
 
 def test_get_hot_items_boardgames(bgg, null_logger):
-
+    time.sleep(10)
     for item in bgg.hot_items("boardgame"):
         assert type(item.id) == int
         assert len(item.name) > 0
@@ -496,7 +540,7 @@ def test_get_hot_items_boardgames(bgg, null_logger):
 
 
 def test_get_hot_items_boardgamepersons(bgg, null_logger):
-
+    time.sleep(10)
     for item in bgg.hot_items("boardgameperson"):
         assert type(item.id) == int
         assert len(item.name) > 0
